@@ -4,17 +4,19 @@ from datetime import datetime
 
 @dataclass
 class EmployeeDTO():
-    restaurant: str
+    restaurant_name: str
+    restaurant_ident: int
     name: str
     altname: str
     role: str
     gen_san_date: str
     gen_tax_payer_id_num: str
     ident: int
+    code: int
 
 
 @dataclass
-class OrderListDTO():
+class OrderDTO():
     visit_id: int
     count_guest: int
     order_id: int
@@ -49,7 +51,7 @@ class WaiterListDTO():
 
 
 @dataclass
-class RestaurantsDTO():
+class RestaurantDTO():
     name: str
     alt_name: str
     ident: int
@@ -119,7 +121,8 @@ class MenuItemsDTO():
 
 @dataclass
 class WaiterDTO():
-    restaurant: str
+    restaurant_name: str
+    restaurant_ident: int
     name: str
     ident: int
     code: int
@@ -143,10 +146,30 @@ class GetVisitDTO():
 
 @dataclass
 class SystemInfoDTO():
-    restaurant: RestaurantsDTO
+    restaurant: RestaurantDTO
     restaurant_code: str
+    shift_date: str
 
 
+@dataclass
+class CategoryDTO():
+    ident: int
+    name: str
+    active_hierarchy: str
+    main_parent_ident: str
+
+
+@dataclass
+class TableDTO():
+    ident: int
+    name: str
+
+
+@dataclass
+class CurrencyDTO():
+    ident: int
+    name: str  
+
 class ConnectionErrors(Exception):
     pass
 
